@@ -158,8 +158,104 @@ date_to_isoyearweek_c.Date <- function(x = lubridate::today()) {
   conversions_date_to[.(x)]$isoyearweek_c
 }
 
+#' ISO quarter (numeric) from Date object
+#'
+#' @param x a Date object or string, in the form of 'yyyy-mm-dd'
+#'
+#' @return ISO quarter in numeric
+#' @export
+#'
+#' @examples
+#' date_to_isoquarter_n("2021-08-11")
+#' date_to_isoquarter_n(lubridate::today())
+date_to_isoquarter_n <- function(x = lubridate::today()) {
+  UseMethod("date_to_isoquarter_n", x)
+}
+
+#' @rdname date_to_isoquarter_n
+#' @export
+date_to_isoquarter_n.default <- function(x) {
+  rep(NA_integer_, length(x))
+}
+
+#' @rdname date_to_isoquarter_n
+#' @export
+date_to_isoquarter_n.character <- function(x = lubridate::today()) {
+  conversions_date_c_to[.(x)]$isoquarter_n
+}
+
+#' @rdname date_to_isoquarter_n
+#' @export
+date_to_isoquarter_n.Date <- function(x = lubridate::today()) {
+  conversions_date_to[.(x)]$isoquarter_n
+}
+
+#' ISO quarter (character) from Date object
+#'
+#' @param x a Date object or string, in the form of 'yyyy-mm-dd'
+#'
+#' @return ISO quarter in character
+#' @export
+#'
+#' @examples
+#' date_to_isoquarter_c("2021-08-11")
+#' date_to_isoquarter_c(lubridate::today())
+date_to_isoquarter_c <- function(x = lubridate::today()) {
+  UseMethod("date_to_isoquarter_c", x)
+}
+
+#' @rdname date_to_isoquarter_c
+#' @export
+date_to_isoquarter_c.default <- function(x) {
+  rep(NA_character_, length(x))
+}
+
+#' @rdname date_to_isoquarter_c
+#' @export
+date_to_isoquarter_c.character <- function(x = lubridate::today()) {
+  conversions_date_c_to[.(x)]$isoquarter_c
+}
+
+#' @rdname date_to_isoquarter_c
+#' @export
+date_to_isoquarter_c.Date <- function(x = lubridate::today()) {
+  conversions_date_to[.(x)]$isoquarter_c
+}
+
+#' ISO year and quarter (character) from Date object
+#'
+#' @param x a Date object or string, in the form of 'yyyy-mm-dd'
+#'
+#' @return ISO year and quarter in character
+#' @export
+#'
+#' @examples
+#' date_to_isoyearquarter_c("2021-08-11")
+#' date_to_isoyearquarter_c(lubridate::today())
+date_to_isoyearquarter_c <- function(x = lubridate::today()) {
+  UseMethod("date_to_isoyearquarter_c", x)
+}
+
+#' @rdname date_to_isoyearquarter_c
+#' @export
+date_to_isoyearquarter_c.default <- function(x) {
+  rep(NA_character_, length(x))
+}
+
+#' @rdname date_to_isoyearquarter_c
+#' @export
+date_to_isoyearquarter_c.character <- function(x = lubridate::today()) {
+  conversions_date_c_to[.(x)]$isoyearquarter_c
+}
+
+#' @rdname date_to_isoyearquarter_c
+#' @export
+date_to_isoyearquarter_c.Date <- function(x = lubridate::today()) {
+  conversions_date_to[.(x)]$isoyearquarter_c
+}
+
 #
-# isoyearweek vs isoyear, isoweek ====
+# isoyearweek vs isoyear, isoweek, isoquarter ====
 #
 
 #' ISO yearweek to year (numeric)
@@ -263,6 +359,80 @@ isoyearweek_to_isoweek_c.character <- function(x) {
   conversions_isoyearweek_to[.(x)]$isoweek_c
 }
 
+#' ISO yearweek to quarter (numeric)
+#'
+#' This function breaks the string connected with '-' into year/quarter
+#' @param x Year-week, e.g. "2020-19" for 19th week in 2020
+#' @return ISO quarter in numeric
+#' @rdname isoyearweek_to_isoquarter_n
+#' @export
+#' @examples 
+#' isoyearweek_to_isoquarter_n('2020-19')
+isoyearweek_to_isoquarter_n <- function(x) {
+  UseMethod("isoyearweek_to_isoquarter_n", x)
+}
+
+#' @rdname isoyearweek_to_isoquarter_n
+#' @export
+isoyearweek_to_isoquarter_n.default <- function(x) {
+  rep(NA_integer_, length(x))
+}
+
+#' @rdname isoyearweek_to_isoquarter_n
+#' @export
+isoyearweek_to_isoquarter_n.character <- function(x) {
+  conversions_isoyearweek_to[.(x)]$isoquarter_n
+}
+
+#' ISO yearweek to quarter (character)
+#'
+#' This function breaks the string connected with '-' into year/quarter
+#' @param x Year-week, e.g. "2020-19" for 19th week in 2020
+#' @return ISO quarter in character
+#' @rdname isoyearweek_to_isoquarter_c
+#' @export
+#' @examples 
+#' isoyearweek_to_isoquarter_c('2020-19')
+isoyearweek_to_isoquarter_c <- function(x) {
+  UseMethod("isoyearweek_to_isoquarter_c", x)
+}
+
+#' @rdname isoyearweek_to_isoquarter_c
+#' @export
+isoyearweek_to_isoquarter_c.default <- function(x) {
+  rep(NA_character_, length(x))
+}
+
+#' @rdname isoyearweek_to_isoquarter_c
+#' @export
+isoyearweek_to_isoquarter_c.character <- function(x) {
+  conversions_isoyearweek_to[.(x)]$isoquarter_c
+}
+
+#' ISO yearweek to ISO yearquarter (character)
+#'
+#' @param x Year-week, e.g. "2020-19" for 19th week in 2020
+#' @return ISO yearquarter in character
+#' @rdname isoyearweek_to_isoyearquarter_c
+#' @export
+#' @examples 
+#' isoyearweek_to_isoyearquarter_c('2020-19')
+isoyearweek_to_isoyearquarter_c <- function(x) {
+  UseMethod("isoyearweek_to_isoyearquarter_c", x)
+}
+
+#' @rdname isoyearweek_to_isoyearquarter_c
+#' @export
+isoyearweek_to_isoyearquarter_c.default <- function(x) {
+  rep(NA_character_, length(x))
+}
+
+#' @rdname isoyearweek_to_isoyearquarter_c
+#' @export
+isoyearweek_to_isoyearquarter_c.character <- function(x) {
+  conversions_isoyearweek_to[.(x)]$isoyearquarter_c
+}
+
 #
 # Downsizing (isoyear -> isoyearweek/date -> date) ====
 #
@@ -384,3 +554,28 @@ isoyearweek_to_last_date.default <- function(x) {
 isoyearweek_to_last_date.character <- function(x) {
   conversions_isoyearweek_to[.(x)]$last_date
 }
+
+#' Last date in season
+#'
+#' Returns the last Sunday in the season
+#' @param x Season, e.g. "2019/2020"
+#' @return Date of last Sunday of that season
+#' @rdname season_to_last_date
+#' @examples
+#' isoyearweek_to_last_date(c("2019-19", "2020-01"))
+#' @export
+season_to_last_date <- function(x) {
+  UseMethod("season_to_last_date", x)
+}
+
+#' @rdname season_to_last_date
+#' @export
+season_to_last_date.default <- function(x) {
+  rep(as.Date(NA), length(x))
+}
+
+#' @rdname season_to_last_date
+#' @export
+season_to_last_date.character <- function(x) {
+  conversions_season_to[.(x)]$last_date
+}
